# PCCM
Python C++ Code Manager

[![Build Status](https://github.com/FindDefinition/PCCM/workflows/build/badge.svg)](https://github.com/FindDefinition/PCCM/actions?query=workflow%3Abuild)

## Milestones

PCCM 1.0: string-based code generation.
PCCM 2.0: ast based code generation and python-c++ execution matching.